#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# Ontology Entities
#------------------------------------------------------------------------------
# Represents various entities (Classes, Object Properties, Data Properties, 
# Individuals) within an ontology.
#==============================================================================

from rdflib import URIRef, BNode
from rdflib.namespace import split_uri

class Entity:
    def __init__(self, reference, graph):
        self.reference = reference
        self.graph = graph

    def properties(self):
        """Retrieve properties associated with the entity."""
        result_list = []
        if self.graph is not None:
            result_list = list(self.graph.predicate_objects(subject=self.reference))
        return result_list

    def name(self):
        raise NotImplementedError("The method name() must be implemented by subclasses.")
        
    def __lt__(self, other):
        """Override the default < (less than) operator to compare entities by their name."""
        if isinstance(other, Entity):
            return self.name() < other.name()
        return NotImplemented


class NamedEntity(Entity):
    def __init__(self, uri, graph):
        super().__init__(uri, graph)
        self.uri = uri

    def __str__(self):
        return str(self.uri)

    def name(self):
        _, entity_name = split_uri(self.uri)
        return entity_name


class BlankEntity(Entity):
    def __init__(self, bnode, graph):
        super().__init__(bnode, graph)
        self.id = str(bnode)

    def __str__(self):
        return f"BNode: {self.id}"

    def name(self):
        return self.id
