#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# Ontology Utilities
#------------------------------------------------------------------------------
# --
#==============================================================================

from rdflib import Graph

# def harmonize_prefixes(graph, source_uri, target_uri):
#     for s, p, o in graph.triples((None, None, None)):
#         s = s if not s.startswith(source_uri) else s.replace(source_uri, target_uri)
#         p = p if not p.startswith(source_uri) else p.replace(source_uri, target_uri)
#         o = o if not isinstance(o, str) or not o.startswith(source_uri) else o.replace(source_uri, target_uri)
#         graph.add((s, p, o))
#     return graph

from rdflib import URIRef

def harmonize_prefixes(graph, source_uri, target_uri):
    triples_to_add = []
    
    # Parcourir les triples et identifier ceux qui nécessitent une modification
    for s, p, o in graph.triples((None, None, None)):
        new_s = URIRef(s.replace(source_uri, target_uri)) if isinstance(s, URIRef) and s.startswith(source_uri) else s
        new_p = URIRef(p.replace(source_uri, target_uri)) if isinstance(p, URIRef) and p.startswith(source_uri) else p
        new_o = o
        
        if isinstance(o, URIRef) and o.startswith(source_uri):
            new_o = URIRef(o.replace(source_uri, target_uri))
        elif isinstance(o, str) and o.startswith(source_uri):
            new_o = o.replace(source_uri, target_uri)
            
        # Si un changement a été effectué, supprimer l'ancien triple et se préparer à ajouter le nouveau
        if s != new_s or p != new_p or o != new_o:
            graph.remove((s, p, o))
            triples_to_add.append((new_s, new_p, new_o))
            
    # Ajouter les nouveaux triples
    for triple in triples_to_add:
        graph.add(triple)
        
    return graph


def extract_prefixes_from_graph(graph):
    return {prefix: namespace for prefix, namespace in graph.namespaces()}

def uri_to_short_form(uri, prefix_mappings, graph_prefixes):
    for prefix, *uris in prefix_mappings:
        for u in uris:
            if u in uri:
                return f"{prefix}:{uri.replace(u, '')}"
    for prefix, namespace in graph_prefixes.items():
        if namespace in uri:
            return f"{prefix}:{uri.replace(namespace, '')}"
    return uri
 
