# test_metric_score.py

import unittest

from context import ontoScorer
from ontoScorer.metric_score import Score

class TestScore(unittest.TestCase):

    def setUp(self):
        self.score = Score()
        self.y_true = [1, 0, 1, 0, 1]
        self.y_pred = [1, 0, 1, 1, 0]

    def test_compute(self):
        self.score.compute(self.y_true, self.y_pred)
        self.assertAlmostEqual(self.score.precision, 0.6666666666666666)  # 2/3
        self.assertAlmostEqual(self.score.recall, 0.6666666666666666)     # 2/3
        self.assertAlmostEqual(self.score.f1, 0.6666666666666666)         # 2/3
        self.assertEqual(self.score.total_elements, 5)
        self.assertEqual(self.score.matched_elements, 3)

    def test_aggregate_f1(self):
        scores = [Score() for _ in range(3)]
        
        # Generating some scores
        y_trues = [[1, 0, 1], [0, 1], [1, 1, 0]]
        y_preds = [[1, 0, 0], [0, 0], [0, 1, 1]]

        for idx, score in enumerate(scores):
            score.compute(y_trues[idx], y_preds[idx])

        aggregated_score = Score.aggregate_f1(scores)
        
        # The aggregated values here are based on the y_trues and y_preds data
        # These should be checked if the y_true and y_pred data is modified.
        self.assertAlmostEqual(aggregated_score.precision, 0.6666666666666666)  # 2/3
        self.assertAlmostEqual(aggregated_score.recall, 0.4)     # 2/5
        self.assertAlmostEqual(aggregated_score.f1, 0.5)  # Harmonic mean of 0.66 and 0.4



if __name__ == "__main__":
    unittest.main()
