#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# test_ontology_modules: Ontology Modules Testing
#------------------------------------------------------------------------------
# Contains tests for verifying functionality of the ontology submodules.
#==============================================================================

import unittest
from rdflib import Graph

# Importing necessary modules from the ontoScorer package for testing.
from context import ontoScorer
from ontoScorer import ontology_utils as ou


class TestOntologyUtils(unittest.TestCase):

    def setUp(self):
        self.equivalent_prefix = [
            ("base", "https://reference.tetras-libre.fr/base-ontology#", "https://tenet.tetras-libre.fr/base-ontology#"),
            ("result", "https://reference.tetras-libre.fr/expected-result#", "https://tenet.tetras-libre.fr/extract-result#")
        ]
        self.rdf_data = """
        @prefix ns1: <https://tenet.tetras-libre.fr/base-ontology#> .
        @prefix owl: <http://www.w3.org/2002/07/owl#> .
        @prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
        """
        self.graph = Graph().parse(data=self.rdf_data, format="turtle")

    def test_uri_to_short_form(self):
        graph_prefixes = ou.extract_prefixes_from_graph(self.graph)
        short_form = ou.uri_to_short_form("https://reference.tetras-libre.fr/expected-result#SolarSystem", self.equivalent_prefix, graph_prefixes)
        self.assertEqual(short_form, "result:SolarSystem")

        short_form2 = ou.uri_to_short_form("http://www.w3.org/2000/01/rdf-schema#label", self.equivalent_prefix, graph_prefixes)
        self.assertEqual(short_form2, "rdfs:label")

if __name__ == '__main__':
    unittest.main()
 
